# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/common/extensions.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import custom_parameter_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2
from google.ads.google_ads.v2.proto.common import feed_common_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2
from google.ads.google_ads.v2.proto.enums import app_store_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__store__pb2
from google.ads.google_ads.v2.proto.enums import call_conversion_reporting_state_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__conversion__reporting__state__pb2
from google.ads.google_ads.v2.proto.enums import price_extension_price_qualifier_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__extension__price__qualifier__pb2
from google.ads.google_ads.v2.proto.enums import price_extension_price_unit_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__extension__price__unit__pb2
from google.ads.google_ads.v2.proto.enums import price_extension_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__extension__type__pb2
from google.ads.google_ads.v2.proto.enums import promotion_extension_discount_modifier_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__extension__discount__modifier__pb2
from google.ads.google_ads.v2.proto.enums import promotion_extension_occasion_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__extension__occasion__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/common/extensions.proto',
  package='google.ads.googleads.v2.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.commonB\017ExtensionsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Common\312\002\036Google\\Ads\\GoogleAds\\V2\\Common\352\002\"Google::Ads::GoogleAds::V2::Common'),
  serialized_pb=_b('\n5google/ads/googleads_v2/proto/common/extensions.proto\x12\x1egoogle.ads.googleads.v2.common\x1a;google/ads/googleads_v2/proto/common/custom_parameter.proto\x1a\x36google/ads/googleads_v2/proto/common/feed_common.proto\x1a\x33google/ads/googleads_v2/proto/enums/app_store.proto\x1aIgoogle/ads/googleads_v2/proto/enums/call_conversion_reporting_state.proto\x1aIgoogle/ads/googleads_v2/proto/enums/price_extension_price_qualifier.proto\x1a\x44google/ads/googleads_v2/proto/enums/price_extension_price_unit.proto\x1a>google/ads/googleads_v2/proto/enums/price_extension_type.proto\x1aOgoogle/ads/googleads_v2/proto/enums/promotion_extension_discount_modifier.proto\x1a\x46google/ads/googleads_v2/proto/enums/promotion_extension_occasion.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xe5\x03\n\x0b\x41ppFeedItem\x12/\n\tlink_text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x61pp_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12G\n\tapp_store\x18\x03 \x01(\x0e\x32\x34.google.ads.googleads.v2.enums.AppStoreEnum.AppStore\x12\x30\n\nfinal_urls\x18\x04 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x66inal_mobile_urls\x18\x05 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15tracking_url_template\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x15url_custom_parameters\x18\x07 \x03(\x0b\x32/.google.ads.googleads.v2.common.CustomParameter\x12\x36\n\x10\x66inal_url_suffix\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xbe\x03\n\x0c\x43\x61llFeedItem\x12\x32\n\x0cphone_number\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x63ountry_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x15\x63\x61ll_tracking_enabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x16\x63\x61ll_conversion_action\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n!call_conversion_tracking_disabled\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x85\x01\n\x1f\x63\x61ll_conversion_reporting_state\x18\x06 \x01(\x0e\x32\\.google.ads.googleads.v2.enums.CallConversionReportingStateEnum.CallConversionReportingState\"E\n\x0f\x43\x61lloutFeedItem\x12\x32\n\x0c\x63\x61llout_text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xaa\x03\n\x10LocationFeedItem\x12\x33\n\rbusiness_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0e\x61\x64\x64ress_line_1\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0e\x61\x64\x64ress_line_2\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x63ity\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08province\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bpostal_code\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x63ountry_code\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0cphone_number\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x94\x04\n\x19\x41\x66\x66iliateLocationFeedItem\x12\x33\n\rbusiness_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0e\x61\x64\x64ress_line_1\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0e\x61\x64\x64ress_line_2\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x63ity\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08province\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bpostal_code\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x63ountry_code\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0cphone_number\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x08\x63hain_id\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\nchain_name\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x94\x02\n\x13TextMessageFeedItem\x12\x33\n\rbusiness_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x63ountry_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0cphone_number\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04text\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0e\x65xtension_text\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xcd\x03\n\rPriceFeedItem\x12V\n\x04type\x18\x01 \x01(\x0e\x32H.google.ads.googleads.v2.enums.PriceExtensionTypeEnum.PriceExtensionType\x12u\n\x0fprice_qualifier\x18\x02 \x01(\x0e\x32\\.google.ads.googleads.v2.enums.PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier\x12;\n\x15tracking_url_template\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rlanguage_code\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x43\n\x0fprice_offerings\x18\x05 \x03(\x0b\x32*.google.ads.googleads.v2.common.PriceOffer\x12\x36\n\x10\x66inal_url_suffix\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf0\x02\n\nPriceOffer\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x05price\x18\x03 \x01(\x0b\x32%.google.ads.googleads.v2.common.Money\x12`\n\x04unit\x18\x04 \x01(\x0e\x32R.google.ads.googleads.v2.enums.PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit\x12\x30\n\nfinal_urls\x18\x05 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x66inal_mobile_urls\x18\x06 \x03(\x0b\x32\x1c.google.protobuf.StringValue\"\xb2\x08\n\x11PromotionFeedItem\x12\x36\n\x10promotion_target\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x83\x01\n\x11\x64iscount_modifier\x18\x02 \x01(\x0e\x32h.google.ads.googleads.v2.enums.PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier\x12:\n\x14promotion_start_date\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12promotion_end_date\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12j\n\x08occasion\x18\t \x01(\x0e\x32X.google.ads.googleads.v2.enums.PromotionExtensionOccasionEnum.PromotionExtensionOccasion\x12\x30\n\nfinal_urls\x18\n \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x66inal_mobile_urls\x18\x0b \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15tracking_url_template\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x15url_custom_parameters\x18\r \x03(\x0b\x32/.google.ads.googleads.v2.common.CustomParameter\x12\x36\n\x10\x66inal_url_suffix\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rlanguage_code\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0bpercent_off\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x00\x12\x41\n\x10money_amount_off\x18\x04 \x01(\x0b\x32%.google.ads.googleads.v2.common.MoneyH\x00\x12\x36\n\x0epromotion_code\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x12\x43\n\x12orders_over_amount\x18\x06 \x01(\x0b\x32%.google.ads.googleads.v2.common.MoneyH\x01\x42\x0f\n\rdiscount_typeB\x13\n\x11promotion_trigger\"w\n\x19StructuredSnippetFeedItem\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06values\x18\x02 \x03(\x0b\x32\x1c.google.protobuf.StringValue\"\xcd\x03\n\x10SitelinkFeedItem\x12/\n\tlink_text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05line1\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05line2\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nfinal_urls\x18\x04 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x66inal_mobile_urls\x18\x05 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15tracking_url_template\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x15url_custom_parameters\x18\x07 \x03(\x0b\x32/.google.ads.googleads.v2.common.CustomParameter\x12\x36\n\x10\x66inal_url_suffix\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"w\n\x14HotelCalloutFeedItem\x12*\n\x04text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rlanguage_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xea\x01\n\"com.google.ads.googleads.v2.commonB\x0f\x45xtensionsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Common\xea\x02\"Google::Ads::GoogleAds::V2::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__store__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__conversion__reporting__state__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__extension__price__qualifier__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__extension__price__unit__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__extension__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__extension__discount__modifier__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__extension__occasion__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_APPFEEDITEM = _descriptor.Descriptor(
  name='AppFeedItem',
  full_name='google.ads.googleads.v2.common.AppFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link_text', full_name='google.ads.googleads.v2.common.AppFeedItem.link_text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='google.ads.googleads.v2.common.AppFeedItem.app_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_store', full_name='google.ads.googleads.v2.common.AppFeedItem.app_store', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_urls', full_name='google.ads.googleads.v2.common.AppFeedItem.final_urls', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_mobile_urls', full_name='google.ads.googleads.v2.common.AppFeedItem.final_mobile_urls', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v2.common.AppFeedItem.tracking_url_template', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v2.common.AppFeedItem.url_custom_parameters', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_url_suffix', full_name='google.ads.googleads.v2.common.AppFeedItem.final_url_suffix', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=1244,
)


_CALLFEEDITEM = _descriptor.Descriptor(
  name='CallFeedItem',
  full_name='google.ads.googleads.v2.common.CallFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='google.ads.googleads.v2.common.CallFeedItem.phone_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v2.common.CallFeedItem.country_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_tracking_enabled', full_name='google.ads.googleads.v2.common.CallFeedItem.call_tracking_enabled', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_conversion_action', full_name='google.ads.googleads.v2.common.CallFeedItem.call_conversion_action', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_conversion_tracking_disabled', full_name='google.ads.googleads.v2.common.CallFeedItem.call_conversion_tracking_disabled', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_conversion_reporting_state', full_name='google.ads.googleads.v2.common.CallFeedItem.call_conversion_reporting_state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1693,
)


_CALLOUTFEEDITEM = _descriptor.Descriptor(
  name='CalloutFeedItem',
  full_name='google.ads.googleads.v2.common.CalloutFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='callout_text', full_name='google.ads.googleads.v2.common.CalloutFeedItem.callout_text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1695,
  serialized_end=1764,
)


_LOCATIONFEEDITEM = _descriptor.Descriptor(
  name='LocationFeedItem',
  full_name='google.ads.googleads.v2.common.LocationFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v2.common.LocationFeedItem.business_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address_line_1', full_name='google.ads.googleads.v2.common.LocationFeedItem.address_line_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address_line_2', full_name='google.ads.googleads.v2.common.LocationFeedItem.address_line_2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='city', full_name='google.ads.googleads.v2.common.LocationFeedItem.city', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='province', full_name='google.ads.googleads.v2.common.LocationFeedItem.province', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postal_code', full_name='google.ads.googleads.v2.common.LocationFeedItem.postal_code', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v2.common.LocationFeedItem.country_code', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='google.ads.googleads.v2.common.LocationFeedItem.phone_number', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1767,
  serialized_end=2193,
)


_AFFILIATELOCATIONFEEDITEM = _descriptor.Descriptor(
  name='AffiliateLocationFeedItem',
  full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.business_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address_line_1', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.address_line_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address_line_2', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.address_line_2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='city', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.city', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='province', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.province', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postal_code', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.postal_code', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.country_code', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.phone_number', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.chain_id', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chain_name', full_name='google.ads.googleads.v2.common.AffiliateLocationFeedItem.chain_name', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2196,
  serialized_end=2728,
)


_TEXTMESSAGEFEEDITEM = _descriptor.Descriptor(
  name='TextMessageFeedItem',
  full_name='google.ads.googleads.v2.common.TextMessageFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v2.common.TextMessageFeedItem.business_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v2.common.TextMessageFeedItem.country_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='google.ads.googleads.v2.common.TextMessageFeedItem.phone_number', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v2.common.TextMessageFeedItem.text', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension_text', full_name='google.ads.googleads.v2.common.TextMessageFeedItem.extension_text', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2731,
  serialized_end=3007,
)


_PRICEFEEDITEM = _descriptor.Descriptor(
  name='PriceFeedItem',
  full_name='google.ads.googleads.v2.common.PriceFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.common.PriceFeedItem.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_qualifier', full_name='google.ads.googleads.v2.common.PriceFeedItem.price_qualifier', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v2.common.PriceFeedItem.tracking_url_template', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='google.ads.googleads.v2.common.PriceFeedItem.language_code', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_offerings', full_name='google.ads.googleads.v2.common.PriceFeedItem.price_offerings', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_url_suffix', full_name='google.ads.googleads.v2.common.PriceFeedItem.final_url_suffix', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3010,
  serialized_end=3471,
)


_PRICEOFFER = _descriptor.Descriptor(
  name='PriceOffer',
  full_name='google.ads.googleads.v2.common.PriceOffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='google.ads.googleads.v2.common.PriceOffer.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.common.PriceOffer.description', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='google.ads.googleads.v2.common.PriceOffer.price', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='google.ads.googleads.v2.common.PriceOffer.unit', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_urls', full_name='google.ads.googleads.v2.common.PriceOffer.final_urls', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_mobile_urls', full_name='google.ads.googleads.v2.common.PriceOffer.final_mobile_urls', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3474,
  serialized_end=3842,
)


_PROMOTIONFEEDITEM = _descriptor.Descriptor(
  name='PromotionFeedItem',
  full_name='google.ads.googleads.v2.common.PromotionFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='promotion_target', full_name='google.ads.googleads.v2.common.PromotionFeedItem.promotion_target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='discount_modifier', full_name='google.ads.googleads.v2.common.PromotionFeedItem.discount_modifier', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='promotion_start_date', full_name='google.ads.googleads.v2.common.PromotionFeedItem.promotion_start_date', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='promotion_end_date', full_name='google.ads.googleads.v2.common.PromotionFeedItem.promotion_end_date', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occasion', full_name='google.ads.googleads.v2.common.PromotionFeedItem.occasion', index=4,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_urls', full_name='google.ads.googleads.v2.common.PromotionFeedItem.final_urls', index=5,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_mobile_urls', full_name='google.ads.googleads.v2.common.PromotionFeedItem.final_mobile_urls', index=6,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v2.common.PromotionFeedItem.tracking_url_template', index=7,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v2.common.PromotionFeedItem.url_custom_parameters', index=8,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_url_suffix', full_name='google.ads.googleads.v2.common.PromotionFeedItem.final_url_suffix', index=9,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='google.ads.googleads.v2.common.PromotionFeedItem.language_code', index=10,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_off', full_name='google.ads.googleads.v2.common.PromotionFeedItem.percent_off', index=11,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='money_amount_off', full_name='google.ads.googleads.v2.common.PromotionFeedItem.money_amount_off', index=12,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='promotion_code', full_name='google.ads.googleads.v2.common.PromotionFeedItem.promotion_code', index=13,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orders_over_amount', full_name='google.ads.googleads.v2.common.PromotionFeedItem.orders_over_amount', index=14,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='discount_type', full_name='google.ads.googleads.v2.common.PromotionFeedItem.discount_type',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='promotion_trigger', full_name='google.ads.googleads.v2.common.PromotionFeedItem.promotion_trigger',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=3845,
  serialized_end=4919,
)


_STRUCTUREDSNIPPETFEEDITEM = _descriptor.Descriptor(
  name='StructuredSnippetFeedItem',
  full_name='google.ads.googleads.v2.common.StructuredSnippetFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='google.ads.googleads.v2.common.StructuredSnippetFeedItem.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='google.ads.googleads.v2.common.StructuredSnippetFeedItem.values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4921,
  serialized_end=5040,
)


_SITELINKFEEDITEM = _descriptor.Descriptor(
  name='SitelinkFeedItem',
  full_name='google.ads.googleads.v2.common.SitelinkFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link_text', full_name='google.ads.googleads.v2.common.SitelinkFeedItem.link_text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line1', full_name='google.ads.googleads.v2.common.SitelinkFeedItem.line1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line2', full_name='google.ads.googleads.v2.common.SitelinkFeedItem.line2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_urls', full_name='google.ads.googleads.v2.common.SitelinkFeedItem.final_urls', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_mobile_urls', full_name='google.ads.googleads.v2.common.SitelinkFeedItem.final_mobile_urls', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v2.common.SitelinkFeedItem.tracking_url_template', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v2.common.SitelinkFeedItem.url_custom_parameters', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_url_suffix', full_name='google.ads.googleads.v2.common.SitelinkFeedItem.final_url_suffix', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5043,
  serialized_end=5504,
)


_HOTELCALLOUTFEEDITEM = _descriptor.Descriptor(
  name='HotelCalloutFeedItem',
  full_name='google.ads.googleads.v2.common.HotelCalloutFeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v2.common.HotelCalloutFeedItem.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='google.ads.googleads.v2.common.HotelCalloutFeedItem.language_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5506,
  serialized_end=5625,
)

_APPFEEDITEM.fields_by_name['link_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPFEEDITEM.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPFEEDITEM.fields_by_name['app_store'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__store__pb2._APPSTOREENUM_APPSTORE
_APPFEEDITEM.fields_by_name['final_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPFEEDITEM.fields_by_name['final_mobile_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPFEEDITEM.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPFEEDITEM.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_APPFEEDITEM.fields_by_name['final_url_suffix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLFEEDITEM.fields_by_name['phone_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLFEEDITEM.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLFEEDITEM.fields_by_name['call_tracking_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLFEEDITEM.fields_by_name['call_conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLFEEDITEM.fields_by_name['call_conversion_tracking_disabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLFEEDITEM.fields_by_name['call_conversion_reporting_state'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__conversion__reporting__state__pb2._CALLCONVERSIONREPORTINGSTATEENUM_CALLCONVERSIONREPORTINGSTATE
_CALLOUTFEEDITEM.fields_by_name['callout_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONFEEDITEM.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONFEEDITEM.fields_by_name['address_line_1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONFEEDITEM.fields_by_name['address_line_2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONFEEDITEM.fields_by_name['city'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONFEEDITEM.fields_by_name['province'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONFEEDITEM.fields_by_name['postal_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONFEEDITEM.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONFEEDITEM.fields_by_name['phone_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['address_line_1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['address_line_2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['city'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['province'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['postal_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['phone_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['chain_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_AFFILIATELOCATIONFEEDITEM.fields_by_name['chain_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMESSAGEFEEDITEM.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMESSAGEFEEDITEM.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMESSAGEFEEDITEM.fields_by_name['phone_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMESSAGEFEEDITEM.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTMESSAGEFEEDITEM.fields_by_name['extension_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRICEFEEDITEM.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__extension__type__pb2._PRICEEXTENSIONTYPEENUM_PRICEEXTENSIONTYPE
_PRICEFEEDITEM.fields_by_name['price_qualifier'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__extension__price__qualifier__pb2._PRICEEXTENSIONPRICEQUALIFIERENUM_PRICEEXTENSIONPRICEQUALIFIER
_PRICEFEEDITEM.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRICEFEEDITEM.fields_by_name['language_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRICEFEEDITEM.fields_by_name['price_offerings'].message_type = _PRICEOFFER
_PRICEFEEDITEM.fields_by_name['final_url_suffix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRICEOFFER.fields_by_name['header'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRICEOFFER.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRICEOFFER.fields_by_name['price'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2._MONEY
_PRICEOFFER.fields_by_name['unit'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__extension__price__unit__pb2._PRICEEXTENSIONPRICEUNITENUM_PRICEEXTENSIONPRICEUNIT
_PRICEOFFER.fields_by_name['final_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRICEOFFER.fields_by_name['final_mobile_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['promotion_target'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['discount_modifier'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__extension__discount__modifier__pb2._PROMOTIONEXTENSIONDISCOUNTMODIFIERENUM_PROMOTIONEXTENSIONDISCOUNTMODIFIER
_PROMOTIONFEEDITEM.fields_by_name['promotion_start_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['promotion_end_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['occasion'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__extension__occasion__pb2._PROMOTIONEXTENSIONOCCASIONENUM_PROMOTIONEXTENSIONOCCASION
_PROMOTIONFEEDITEM.fields_by_name['final_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['final_mobile_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_PROMOTIONFEEDITEM.fields_by_name['final_url_suffix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['language_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['percent_off'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_PROMOTIONFEEDITEM.fields_by_name['money_amount_off'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2._MONEY
_PROMOTIONFEEDITEM.fields_by_name['promotion_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROMOTIONFEEDITEM.fields_by_name['orders_over_amount'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2._MONEY
_PROMOTIONFEEDITEM.oneofs_by_name['discount_type'].fields.append(
  _PROMOTIONFEEDITEM.fields_by_name['percent_off'])
_PROMOTIONFEEDITEM.fields_by_name['percent_off'].containing_oneof = _PROMOTIONFEEDITEM.oneofs_by_name['discount_type']
_PROMOTIONFEEDITEM.oneofs_by_name['discount_type'].fields.append(
  _PROMOTIONFEEDITEM.fields_by_name['money_amount_off'])
_PROMOTIONFEEDITEM.fields_by_name['money_amount_off'].containing_oneof = _PROMOTIONFEEDITEM.oneofs_by_name['discount_type']
_PROMOTIONFEEDITEM.oneofs_by_name['promotion_trigger'].fields.append(
  _PROMOTIONFEEDITEM.fields_by_name['promotion_code'])
_PROMOTIONFEEDITEM.fields_by_name['promotion_code'].containing_oneof = _PROMOTIONFEEDITEM.oneofs_by_name['promotion_trigger']
_PROMOTIONFEEDITEM.oneofs_by_name['promotion_trigger'].fields.append(
  _PROMOTIONFEEDITEM.fields_by_name['orders_over_amount'])
_PROMOTIONFEEDITEM.fields_by_name['orders_over_amount'].containing_oneof = _PROMOTIONFEEDITEM.oneofs_by_name['promotion_trigger']
_STRUCTUREDSNIPPETFEEDITEM.fields_by_name['header'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STRUCTUREDSNIPPETFEEDITEM.fields_by_name['values'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SITELINKFEEDITEM.fields_by_name['link_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SITELINKFEEDITEM.fields_by_name['line1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SITELINKFEEDITEM.fields_by_name['line2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SITELINKFEEDITEM.fields_by_name['final_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SITELINKFEEDITEM.fields_by_name['final_mobile_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SITELINKFEEDITEM.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SITELINKFEEDITEM.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_SITELINKFEEDITEM.fields_by_name['final_url_suffix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_HOTELCALLOUTFEEDITEM.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_HOTELCALLOUTFEEDITEM.fields_by_name['language_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['AppFeedItem'] = _APPFEEDITEM
DESCRIPTOR.message_types_by_name['CallFeedItem'] = _CALLFEEDITEM
DESCRIPTOR.message_types_by_name['CalloutFeedItem'] = _CALLOUTFEEDITEM
DESCRIPTOR.message_types_by_name['LocationFeedItem'] = _LOCATIONFEEDITEM
DESCRIPTOR.message_types_by_name['AffiliateLocationFeedItem'] = _AFFILIATELOCATIONFEEDITEM
DESCRIPTOR.message_types_by_name['TextMessageFeedItem'] = _TEXTMESSAGEFEEDITEM
DESCRIPTOR.message_types_by_name['PriceFeedItem'] = _PRICEFEEDITEM
DESCRIPTOR.message_types_by_name['PriceOffer'] = _PRICEOFFER
DESCRIPTOR.message_types_by_name['PromotionFeedItem'] = _PROMOTIONFEEDITEM
DESCRIPTOR.message_types_by_name['StructuredSnippetFeedItem'] = _STRUCTUREDSNIPPETFEEDITEM
DESCRIPTOR.message_types_by_name['SitelinkFeedItem'] = _SITELINKFEEDITEM
DESCRIPTOR.message_types_by_name['HotelCalloutFeedItem'] = _HOTELCALLOUTFEEDITEM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppFeedItem = _reflection.GeneratedProtocolMessageType('AppFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _APPFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents an App extension.
  
  
  Attributes:
      link_text:
          The visible text displayed when the link is rendered in an ad.
          This string must not be empty, and the length of this string
          should be between 1 and 25, inclusive.
      app_id:
          The store-specific ID for the target application. This string
          must not be empty.
      app_store:
          The application store that the target application belongs to.
          This field is required.
      final_urls:
          A list of possible final URLs after all cross domain
          redirects. This list must not be empty.
      final_mobile_urls:
          A list of possible final mobile URLs after all cross domain
          redirects.
      tracking_url_template:
          URL template for constructing a tracking URL. Default value is
          "{lpurl}".
      url_custom_parameters:
          A list of mappings to be used for substituting URL custom
          parameter tags in the tracking\_url\_template, final\_urls,
          and/or final\_mobile\_urls.
      final_url_suffix:
          URL template for appending params to landing page URLs served
          with parallel tracking.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.AppFeedItem)
  ))
_sym_db.RegisterMessage(AppFeedItem)

CallFeedItem = _reflection.GeneratedProtocolMessageType('CallFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _CALLFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents a Call extension.
  
  
  Attributes:
      phone_number:
          The advertiser's phone number to append to the ad. This string
          must not be empty.
      country_code:
          Uppercase two-letter country code of the advertiser's phone
          number. This string must not be empty.
      call_tracking_enabled:
          Indicates whether call tracking is enabled. By default, call
          tracking is not enabled.
      call_conversion_action:
          The conversion action to attribute a call conversion to. If
          not set a default conversion action is used. This field only
          has effect if call\_tracking\_enabled is set to true.
          Otherwise this field is ignored.
      call_conversion_tracking_disabled:
          If true, disable call conversion tracking.
          call\_conversion\_action should not be set if this is true.
          Optional.
      call_conversion_reporting_state:
          Enum value that indicates whether this call extension uses its
          own call conversion setting (or just have call conversion
          disabled), or following the account level setting.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.CallFeedItem)
  ))
_sym_db.RegisterMessage(CallFeedItem)

CalloutFeedItem = _reflection.GeneratedProtocolMessageType('CalloutFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _CALLOUTFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents a callout extension.
  
  
  Attributes:
      callout_text:
          The callout text. The length of this string should be between
          1 and 25, inclusive.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.CalloutFeedItem)
  ))
_sym_db.RegisterMessage(CalloutFeedItem)

LocationFeedItem = _reflection.GeneratedProtocolMessageType('LocationFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _LOCATIONFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents a location extension.
  
  
  Attributes:
      business_name:
          The name of the business.
      address_line_1:
          Line 1 of the business address.
      address_line_2:
          Line 2 of the business address.
      city:
          City of the business address.
      province:
          Province of the business address.
      postal_code:
          Postal code of the business address.
      country_code:
          Country code of the business address.
      phone_number:
          Phone number of the business.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.LocationFeedItem)
  ))
_sym_db.RegisterMessage(LocationFeedItem)

AffiliateLocationFeedItem = _reflection.GeneratedProtocolMessageType('AffiliateLocationFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _AFFILIATELOCATIONFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents an affiliate location extension.
  
  
  Attributes:
      business_name:
          The name of the business.
      address_line_1:
          Line 1 of the business address.
      address_line_2:
          Line 2 of the business address.
      city:
          City of the business address.
      province:
          Province of the business address.
      postal_code:
          Postal code of the business address.
      country_code:
          Country code of the business address.
      phone_number:
          Phone number of the business.
      chain_id:
          Id of the retail chain that is advertised as a seller of your
          product.
      chain_name:
          Name of chain.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.AffiliateLocationFeedItem)
  ))
_sym_db.RegisterMessage(AffiliateLocationFeedItem)

TextMessageFeedItem = _reflection.GeneratedProtocolMessageType('TextMessageFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _TEXTMESSAGEFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """An extension that users can click on to send a text message to the
  advertiser.
  
  
  Attributes:
      business_name:
          The business name to prepend to the message text. This field
          is required.
      country_code:
          Uppercase two-letter country code of the advertiser's phone
          number. This field is required.
      phone_number:
          The advertiser's phone number the message will be sent to.
          Required.
      text:
          The text to show in the ad. This field is required.
      extension_text:
          The message text populated in the messaging app.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.TextMessageFeedItem)
  ))
_sym_db.RegisterMessage(TextMessageFeedItem)

PriceFeedItem = _reflection.GeneratedProtocolMessageType('PriceFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _PRICEFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents a Price extension.
  
  
  Attributes:
      type:
          Price extension type of this extension.
      price_qualifier:
          Price qualifier for all offers of this price extension.
      tracking_url_template:
          Tracking URL template for all offers of this price extension.
      language_code:
          The code of the language used for this price extension.
      price_offerings:
          The price offerings in this price extension.
      final_url_suffix:
          URL template for appending params to landing page URLs served
          with parallel tracking.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.PriceFeedItem)
  ))
_sym_db.RegisterMessage(PriceFeedItem)

PriceOffer = _reflection.GeneratedProtocolMessageType('PriceOffer', (_message.Message,), dict(
  DESCRIPTOR = _PRICEOFFER,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents one price offer in a price extension.
  
  
  Attributes:
      header:
          Header text of this offer.
      description:
          Description text of this offer.
      price:
          Price value of this offer.
      unit:
          Price unit for this offer.
      final_urls:
          A list of possible final URLs after all cross domain
          redirects.
      final_mobile_urls:
          A list of possible final mobile URLs after all cross domain
          redirects.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.PriceOffer)
  ))
_sym_db.RegisterMessage(PriceOffer)

PromotionFeedItem = _reflection.GeneratedProtocolMessageType('PromotionFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _PROMOTIONFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents a Promotion extension.
  
  
  Attributes:
      promotion_target:
          A freeform description of what the promotion is targeting.
          This field is required.
      discount_modifier:
          Enum that modifies the qualification of the discount.
      promotion_start_date:
          Start date of when the promotion is eligible to be redeemed.
      promotion_end_date:
          End date of when the promotion is eligible to be redeemed.
      occasion:
          The occasion the promotion was intended for. If an occasion is
          set, the redemption window will need to fall within the date
          range associated with the occasion.
      final_urls:
          A list of possible final URLs after all cross domain
          redirects. This field is required.
      final_mobile_urls:
          A list of possible final mobile URLs after all cross domain
          redirects.
      tracking_url_template:
          URL template for constructing a tracking URL.
      url_custom_parameters:
          A list of mappings to be used for substituting URL custom
          parameter tags in the tracking\_url\_template, final\_urls,
          and/or final\_mobile\_urls.
      final_url_suffix:
          URL template for appending params to landing page URLs served
          with parallel tracking.
      language_code:
          The language of the promotion. Represented as BCP 47 language
          tag.
      discount_type:
          Discount type, can be percentage off or amount off.
      percent_off:
          Percentage off discount in the promotion in micros. One
          million is equivalent to one percent. Either this or
          money\_off\_amount is required.
      money_amount_off:
          Money amount off for discount in the promotion. Either this or
          percent\_off is required.
      promotion_trigger:
          Promotion trigger. Can be by promotion code or promo by
          eligible order amount.
      promotion_code:
          A code the user should use in order to be eligible for the
          promotion.
      orders_over_amount:
          The amount the total order needs to be for the user to be
          eligible for the promotion.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.PromotionFeedItem)
  ))
_sym_db.RegisterMessage(PromotionFeedItem)

StructuredSnippetFeedItem = _reflection.GeneratedProtocolMessageType('StructuredSnippetFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _STRUCTUREDSNIPPETFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents a structured snippet extension.
  
  
  Attributes:
      header:
          The header of the snippet. This string must not be empty.
      values:
          The values in the snippet. The maximum size of this collection
          is 10.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.StructuredSnippetFeedItem)
  ))
_sym_db.RegisterMessage(StructuredSnippetFeedItem)

SitelinkFeedItem = _reflection.GeneratedProtocolMessageType('SitelinkFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _SITELINKFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents a sitelink extension.
  
  
  Attributes:
      link_text:
          URL display text for the sitelink. The length of this string
          should be between 1 and 25, inclusive.
      line1:
          First line of the description for the sitelink. If this value
          is set, line2 must also be set. The length of this string
          should be between 0 and 35, inclusive.
      line2:
          Second line of the description for the sitelink. If this value
          is set, line1 must also be set. The length of this string
          should be between 0 and 35, inclusive.
      final_urls:
          A list of possible final URLs after all cross domain
          redirects.
      final_mobile_urls:
          A list of possible final mobile URLs after all cross domain
          redirects.
      tracking_url_template:
          URL template for constructing a tracking URL.
      url_custom_parameters:
          A list of mappings to be used for substituting URL custom
          parameter tags in the tracking\_url\_template, final\_urls,
          and/or final\_mobile\_urls.
      final_url_suffix:
          Final URL suffix to be appended to landing page URLs served
          with parallel tracking.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.SitelinkFeedItem)
  ))
_sym_db.RegisterMessage(SitelinkFeedItem)

HotelCalloutFeedItem = _reflection.GeneratedProtocolMessageType('HotelCalloutFeedItem', (_message.Message,), dict(
  DESCRIPTOR = _HOTELCALLOUTFEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.common.extensions_pb2'
  ,
  __doc__ = """Represents a hotel callout extension.
  
  
  Attributes:
      text:
          The callout text. The length of this string should be between
          1 and 25, inclusive.
      language_code:
          The language of the hotel callout text. IETF BCP 47 compliant
          language code.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.HotelCalloutFeedItem)
  ))
_sym_db.RegisterMessage(HotelCalloutFeedItem)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/asset.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import asset_types_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_asset__types__pb2
from google.ads.google_ads.v2.proto.enums import asset_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_asset__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/asset.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\nAssetProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n3google/ads/googleads_v2/proto/resources/asset.proto\x12!google.ads.googleads.v2.resources\x1a\x36google/ads/googleads_v2/proto/common/asset_types.proto\x1a\x34google/ads/googleads_v2/proto/enums/asset_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xed\x03\n\x05\x41sset\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x44\n\x04type\x18\x04 \x01(\x0e\x32\x36.google.ads.googleads.v2.enums.AssetTypeEnum.AssetType\x12P\n\x13youtube_video_asset\x18\x05 \x01(\x0b\x32\x31.google.ads.googleads.v2.common.YoutubeVideoAssetH\x00\x12N\n\x12media_bundle_asset\x18\x06 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.MediaBundleAssetH\x00\x12\x41\n\x0bimage_asset\x18\x07 \x01(\x0b\x32*.google.ads.googleads.v2.common.ImageAssetH\x00\x12?\n\ntext_asset\x18\x08 \x01(\x0b\x32).google.ads.googleads.v2.common.TextAssetH\x00\x42\x0c\n\nasset_dataB\xf7\x01\n%com.google.ads.googleads.v2.resourcesB\nAssetProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_asset__types__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_asset__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ASSET = _descriptor.Descriptor(
  name='Asset',
  full_name='google.ads.googleads.v2.resources.Asset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.Asset.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.Asset.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.Asset.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.Asset.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_video_asset', full_name='google.ads.googleads.v2.resources.Asset.youtube_video_asset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_bundle_asset', full_name='google.ads.googleads.v2.resources.Asset.media_bundle_asset', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_asset', full_name='google.ads.googleads.v2.resources.Asset.image_asset', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_asset', full_name='google.ads.googleads.v2.resources.Asset.text_asset', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='asset_data', full_name='google.ads.googleads.v2.resources.Asset.asset_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=263,
  serialized_end=756,
)

_ASSET.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ASSET.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ASSET.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_asset__type__pb2._ASSETTYPEENUM_ASSETTYPE
_ASSET.fields_by_name['youtube_video_asset'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_asset__types__pb2._YOUTUBEVIDEOASSET
_ASSET.fields_by_name['media_bundle_asset'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_asset__types__pb2._MEDIABUNDLEASSET
_ASSET.fields_by_name['image_asset'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_asset__types__pb2._IMAGEASSET
_ASSET.fields_by_name['text_asset'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_asset__types__pb2._TEXTASSET
_ASSET.oneofs_by_name['asset_data'].fields.append(
  _ASSET.fields_by_name['youtube_video_asset'])
_ASSET.fields_by_name['youtube_video_asset'].containing_oneof = _ASSET.oneofs_by_name['asset_data']
_ASSET.oneofs_by_name['asset_data'].fields.append(
  _ASSET.fields_by_name['media_bundle_asset'])
_ASSET.fields_by_name['media_bundle_asset'].containing_oneof = _ASSET.oneofs_by_name['asset_data']
_ASSET.oneofs_by_name['asset_data'].fields.append(
  _ASSET.fields_by_name['image_asset'])
_ASSET.fields_by_name['image_asset'].containing_oneof = _ASSET.oneofs_by_name['asset_data']
_ASSET.oneofs_by_name['asset_data'].fields.append(
  _ASSET.fields_by_name['text_asset'])
_ASSET.fields_by_name['text_asset'].containing_oneof = _ASSET.oneofs_by_name['asset_data']
DESCRIPTOR.message_types_by_name['Asset'] = _ASSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), dict(
  DESCRIPTOR = _ASSET,
  __module__ = 'google.ads.googleads_v2.proto.resources.asset_pb2'
  ,
  __doc__ = """Asset is a part of an ad which can be shared across multiple ads. It can
  be an image (ImageAsset), a video (YoutubeVideoAsset), etc.
  
  
  Attributes:
      resource_name:
          The resource name of the asset. Asset resource names have the
          form:  ``customers/{customer_id}/assets/{asset_id}``
      id:
          The ID of the asset.
      name:
          Optional name of the asset.
      type:
          Type of the asset.
      asset_data:
          The specific type of the asset.
      youtube_video_asset:
          A YouTube video asset.
      media_bundle_asset:
          A media bundle asset.
      image_asset:
          An image asset.
      text_asset:
          A text asset.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Asset)
  ))
_sym_db.RegisterMessage(Asset)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/simulation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/simulation.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\017SimulationProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n5google/ads/googleads_v1/proto/common/simulation.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"l\n\x1e\x42idModifierSimulationPointList\x12J\n\x06points\x18\x01 \x03(\x0b\x32:.google.ads.googleads.v1.common.BidModifierSimulationPoint\"b\n\x19\x43pcBidSimulationPointList\x12\x45\n\x06points\x18\x01 \x03(\x0b\x32\x35.google.ads.googleads.v1.common.CpcBidSimulationPoint\"b\n\x19\x43pvBidSimulationPointList\x12\x45\n\x06points\x18\x01 \x03(\x0b\x32\x35.google.ads.googleads.v1.common.CpvBidSimulationPoint\"h\n\x1cTargetCpaSimulationPointList\x12H\n\x06points\x18\x01 \x03(\x0b\x32\x38.google.ads.googleads.v1.common.TargetCpaSimulationPoint\"\x8e\x06\n\x1a\x42idModifierSimulationPoint\x12\x32\n\x0c\x62id_modifier\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x14\x62iddable_conversions\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12@\n\x1a\x62iddable_conversions_value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06\x63licks\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0b\x63ost_micros\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0bimpressions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14top_slot_impressions\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x41\n\x1bparent_biddable_conversions\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12G\n!parent_biddable_conversions_value\x18\t \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\rparent_clicks\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12parent_cost_micros\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12parent_impressions\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bparent_top_slot_impressions\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x96\x03\n\x15\x43pcBidSimulationPoint\x12\x33\n\x0e\x63pc_bid_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x14\x62iddable_conversions\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12@\n\x1a\x62iddable_conversions_value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06\x63licks\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0b\x63ost_micros\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0bimpressions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14top_slot_impressions\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xb0\x01\n\x15\x43pvBidSimulationPoint\x12\x33\n\x0e\x63pv_bid_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0b\x63ost_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0bimpressions\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x9c\x03\n\x18TargetCpaSimulationPoint\x12\x36\n\x11target_cpa_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x14\x62iddable_conversions\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12@\n\x1a\x62iddable_conversions_value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06\x63licks\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0b\x63ost_micros\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0bimpressions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14top_slot_impressions\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\xea\x01\n\"com.google.ads.googleads.v1.commonB\x0fSimulationProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_BIDMODIFIERSIMULATIONPOINTLIST = _descriptor.Descriptor(
  name='BidModifierSimulationPointList',
  full_name='google.ads.googleads.v1.common.BidModifierSimulationPointList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='google.ads.googleads.v1.common.BidModifierSimulationPointList.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=259,
)


_CPCBIDSIMULATIONPOINTLIST = _descriptor.Descriptor(
  name='CpcBidSimulationPointList',
  full_name='google.ads.googleads.v1.common.CpcBidSimulationPointList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='google.ads.googleads.v1.common.CpcBidSimulationPointList.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=359,
)


_CPVBIDSIMULATIONPOINTLIST = _descriptor.Descriptor(
  name='CpvBidSimulationPointList',
  full_name='google.ads.googleads.v1.common.CpvBidSimulationPointList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='google.ads.googleads.v1.common.CpvBidSimulationPointList.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=459,
)


_TARGETCPASIMULATIONPOINTLIST = _descriptor.Descriptor(
  name='TargetCpaSimulationPointList',
  full_name='google.ads.googleads.v1.common.TargetCpaSimulationPointList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='google.ads.googleads.v1.common.TargetCpaSimulationPointList.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=461,
  serialized_end=565,
)


_BIDMODIFIERSIMULATIONPOINT = _descriptor.Descriptor(
  name='BidModifierSimulationPoint',
  full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bid_modifier', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.bid_modifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biddable_conversions', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.biddable_conversions', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biddable_conversions_value', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.biddable_conversions_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clicks', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.clicks', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_micros', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.cost_micros', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impressions', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.impressions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_slot_impressions', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.top_slot_impressions', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_biddable_conversions', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.parent_biddable_conversions', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_biddable_conversions_value', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.parent_biddable_conversions_value', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_clicks', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.parent_clicks', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_cost_micros', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.parent_cost_micros', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_impressions', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.parent_impressions', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_top_slot_impressions', full_name='google.ads.googleads.v1.common.BidModifierSimulationPoint.parent_top_slot_impressions', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=1350,
)


_CPCBIDSIMULATIONPOINT = _descriptor.Descriptor(
  name='CpcBidSimulationPoint',
  full_name='google.ads.googleads.v1.common.CpcBidSimulationPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpc_bid_micros', full_name='google.ads.googleads.v1.common.CpcBidSimulationPoint.cpc_bid_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biddable_conversions', full_name='google.ads.googleads.v1.common.CpcBidSimulationPoint.biddable_conversions', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biddable_conversions_value', full_name='google.ads.googleads.v1.common.CpcBidSimulationPoint.biddable_conversions_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clicks', full_name='google.ads.googleads.v1.common.CpcBidSimulationPoint.clicks', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_micros', full_name='google.ads.googleads.v1.common.CpcBidSimulationPoint.cost_micros', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impressions', full_name='google.ads.googleads.v1.common.CpcBidSimulationPoint.impressions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_slot_impressions', full_name='google.ads.googleads.v1.common.CpcBidSimulationPoint.top_slot_impressions', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1759,
)


_CPVBIDSIMULATIONPOINT = _descriptor.Descriptor(
  name='CpvBidSimulationPoint',
  full_name='google.ads.googleads.v1.common.CpvBidSimulationPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpv_bid_micros', full_name='google.ads.googleads.v1.common.CpvBidSimulationPoint.cpv_bid_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_micros', full_name='google.ads.googleads.v1.common.CpvBidSimulationPoint.cost_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impressions', full_name='google.ads.googleads.v1.common.CpvBidSimulationPoint.impressions', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1762,
  serialized_end=1938,
)


_TARGETCPASIMULATIONPOINT = _descriptor.Descriptor(
  name='TargetCpaSimulationPoint',
  full_name='google.ads.googleads.v1.common.TargetCpaSimulationPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_cpa_micros', full_name='google.ads.googleads.v1.common.TargetCpaSimulationPoint.target_cpa_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biddable_conversions', full_name='google.ads.googleads.v1.common.TargetCpaSimulationPoint.biddable_conversions', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biddable_conversions_value', full_name='google.ads.googleads.v1.common.TargetCpaSimulationPoint.biddable_conversions_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clicks', full_name='google.ads.googleads.v1.common.TargetCpaSimulationPoint.clicks', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_micros', full_name='google.ads.googleads.v1.common.TargetCpaSimulationPoint.cost_micros', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impressions', full_name='google.ads.googleads.v1.common.TargetCpaSimulationPoint.impressions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_slot_impressions', full_name='google.ads.googleads.v1.common.TargetCpaSimulationPoint.top_slot_impressions', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1941,
  serialized_end=2353,
)

_BIDMODIFIERSIMULATIONPOINTLIST.fields_by_name['points'].message_type = _BIDMODIFIERSIMULATIONPOINT
_CPCBIDSIMULATIONPOINTLIST.fields_by_name['points'].message_type = _CPCBIDSIMULATIONPOINT
_CPVBIDSIMULATIONPOINTLIST.fields_by_name['points'].message_type = _CPVBIDSIMULATIONPOINT
_TARGETCPASIMULATIONPOINTLIST.fields_by_name['points'].message_type = _TARGETCPASIMULATIONPOINT
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['bid_modifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['biddable_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['biddable_conversions_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['top_slot_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['parent_biddable_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['parent_biddable_conversions_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['parent_clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['parent_cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['parent_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDMODIFIERSIMULATIONPOINT.fields_by_name['parent_top_slot_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CPCBIDSIMULATIONPOINT.fields_by_name['cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CPCBIDSIMULATIONPOINT.fields_by_name['biddable_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CPCBIDSIMULATIONPOINT.fields_by_name['biddable_conversions_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CPCBIDSIMULATIONPOINT.fields_by_name['clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CPCBIDSIMULATIONPOINT.fields_by_name['cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CPCBIDSIMULATIONPOINT.fields_by_name['impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CPCBIDSIMULATIONPOINT.fields_by_name['top_slot_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CPVBIDSIMULATIONPOINT.fields_by_name['cpv_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CPVBIDSIMULATIONPOINT.fields_by_name['cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CPVBIDSIMULATIONPOINT.fields_by_name['impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETCPASIMULATIONPOINT.fields_by_name['target_cpa_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETCPASIMULATIONPOINT.fields_by_name['biddable_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_TARGETCPASIMULATIONPOINT.fields_by_name['biddable_conversions_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_TARGETCPASIMULATIONPOINT.fields_by_name['clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETCPASIMULATIONPOINT.fields_by_name['cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETCPASIMULATIONPOINT.fields_by_name['impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETCPASIMULATIONPOINT.fields_by_name['top_slot_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['BidModifierSimulationPointList'] = _BIDMODIFIERSIMULATIONPOINTLIST
DESCRIPTOR.message_types_by_name['CpcBidSimulationPointList'] = _CPCBIDSIMULATIONPOINTLIST
DESCRIPTOR.message_types_by_name['CpvBidSimulationPointList'] = _CPVBIDSIMULATIONPOINTLIST
DESCRIPTOR.message_types_by_name['TargetCpaSimulationPointList'] = _TARGETCPASIMULATIONPOINTLIST
DESCRIPTOR.message_types_by_name['BidModifierSimulationPoint'] = _BIDMODIFIERSIMULATIONPOINT
DESCRIPTOR.message_types_by_name['CpcBidSimulationPoint'] = _CPCBIDSIMULATIONPOINT
DESCRIPTOR.message_types_by_name['CpvBidSimulationPoint'] = _CPVBIDSIMULATIONPOINT
DESCRIPTOR.message_types_by_name['TargetCpaSimulationPoint'] = _TARGETCPASIMULATIONPOINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BidModifierSimulationPointList = _reflection.GeneratedProtocolMessageType('BidModifierSimulationPointList', (_message.Message,), dict(
  DESCRIPTOR = _BIDMODIFIERSIMULATIONPOINTLIST,
  __module__ = 'google.ads.googleads_v1.proto.common.simulation_pb2'
  ,
  __doc__ = """A container for simulation points for simulations of type BID\_MODIFIER.
  
  
  Attributes:
      points:
          Projected metrics for a series of bid modifier amounts.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.BidModifierSimulationPointList)
  ))
_sym_db.RegisterMessage(BidModifierSimulationPointList)

CpcBidSimulationPointList = _reflection.GeneratedProtocolMessageType('CpcBidSimulationPointList', (_message.Message,), dict(
  DESCRIPTOR = _CPCBIDSIMULATIONPOINTLIST,
  __module__ = 'google.ads.googleads_v1.proto.common.simulation_pb2'
  ,
  __doc__ = """A container for simulation points for simulations of type CPC\_BID.
  
  
  Attributes:
      points:
          Projected metrics for a series of CPC bid amounts.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CpcBidSimulationPointList)
  ))
_sym_db.RegisterMessage(CpcBidSimulationPointList)

CpvBidSimulationPointList = _reflection.GeneratedProtocolMessageType('CpvBidSimulationPointList', (_message.Message,), dict(
  DESCRIPTOR = _CPVBIDSIMULATIONPOINTLIST,
  __module__ = 'google.ads.googleads_v1.proto.common.simulation_pb2'
  ,
  __doc__ = """A container for simulation points for simulations of type CPV\_BID.
  
  
  Attributes:
      points:
          Projected metrics for a series of CPV bid amounts.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CpvBidSimulationPointList)
  ))
_sym_db.RegisterMessage(CpvBidSimulationPointList)

TargetCpaSimulationPointList = _reflection.GeneratedProtocolMessageType('TargetCpaSimulationPointList', (_message.Message,), dict(
  DESCRIPTOR = _TARGETCPASIMULATIONPOINTLIST,
  __module__ = 'google.ads.googleads_v1.proto.common.simulation_pb2'
  ,
  __doc__ = """A container for simulation points for simulations of type TARGET\_CPA.
  
  
  Attributes:
      points:
          Projected metrics for a series of target CPA amounts.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetCpaSimulationPointList)
  ))
_sym_db.RegisterMessage(TargetCpaSimulationPointList)

BidModifierSimulationPoint = _reflection.GeneratedProtocolMessageType('BidModifierSimulationPoint', (_message.Message,), dict(
  DESCRIPTOR = _BIDMODIFIERSIMULATIONPOINT,
  __module__ = 'google.ads.googleads_v1.proto.common.simulation_pb2'
  ,
  __doc__ = """Projected metrics for a specific bid modifier amount.
  
  
  Attributes:
      bid_modifier:
          The simulated bid modifier upon which projected metrics are
          based.
      biddable_conversions:
          Projected number of biddable conversions.
      biddable_conversions_value:
          Projected total value of biddable conversions.
      clicks:
          Projected number of clicks.
      cost_micros:
          Projected cost in micros.
      impressions:
          Projected number of impressions.
      top_slot_impressions:
          Projected number of top slot impressions.
      parent_biddable_conversions:
          Projected number of biddable conversions for the parent
          resource.
      parent_biddable_conversions_value:
          Projected total value of biddable conversions for the parent
          resource.
      parent_clicks:
          Projected number of clicks for the parent resource.
      parent_cost_micros:
          Projected cost in micros for the parent resource.
      parent_impressions:
          Projected number of impressions for the parent resource.
      parent_top_slot_impressions:
          Projected number of top slot impressions for the parent
          resource.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.BidModifierSimulationPoint)
  ))
_sym_db.RegisterMessage(BidModifierSimulationPoint)

CpcBidSimulationPoint = _reflection.GeneratedProtocolMessageType('CpcBidSimulationPoint', (_message.Message,), dict(
  DESCRIPTOR = _CPCBIDSIMULATIONPOINT,
  __module__ = 'google.ads.googleads_v1.proto.common.simulation_pb2'
  ,
  __doc__ = """Projected metrics for a specific CPC bid amount.
  
  
  Attributes:
      cpc_bid_micros:
          The simulated CPC bid upon which projected metrics are based.
      biddable_conversions:
          Projected number of biddable conversions.
      biddable_conversions_value:
          Projected total value of biddable conversions.
      clicks:
          Projected number of clicks.
      cost_micros:
          Projected cost in micros.
      impressions:
          Projected number of impressions.
      top_slot_impressions:
          Projected number of top slot impressions. Display network does
          not support this field at the ad group level.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CpcBidSimulationPoint)
  ))
_sym_db.RegisterMessage(CpcBidSimulationPoint)

CpvBidSimulationPoint = _reflection.GeneratedProtocolMessageType('CpvBidSimulationPoint', (_message.Message,), dict(
  DESCRIPTOR = _CPVBIDSIMULATIONPOINT,
  __module__ = 'google.ads.googleads_v1.proto.common.simulation_pb2'
  ,
  __doc__ = """Projected metrics for a specific CPV bid amount.
  
  
  Attributes:
      cpv_bid_micros:
          The simulated CPV bid upon which projected metrics are based.
      cost_micros:
          Projected cost in micros.
      impressions:
          Projected number of impressions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CpvBidSimulationPoint)
  ))
_sym_db.RegisterMessage(CpvBidSimulationPoint)

TargetCpaSimulationPoint = _reflection.GeneratedProtocolMessageType('TargetCpaSimulationPoint', (_message.Message,), dict(
  DESCRIPTOR = _TARGETCPASIMULATIONPOINT,
  __module__ = 'google.ads.googleads_v1.proto.common.simulation_pb2'
  ,
  __doc__ = """Projected metrics for a specific target CPA amount.
  
  
  Attributes:
      target_cpa_micros:
          The simulated target CPA upon which projected metrics are
          based.
      biddable_conversions:
          Projected number of biddable conversions.
      biddable_conversions_value:
          Projected total value of biddable conversions.
      clicks:
          Projected number of clicks.
      cost_micros:
          Projected cost in micros.
      impressions:
          Projected number of impressions.
      top_slot_impressions:
          Projected number of top slot impressions. Display network does
          not support this field at the ad group level.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetCpaSimulationPoint)
  ))
_sym_db.RegisterMessage(TargetCpaSimulationPoint)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A mixin class to store shared functionality for all the gRPC Interceptors.

This mixin class centralizes sets of functionality that are common across all
Interceptors, including retrieving data from gRPC metadata and initializing
instances of grpc.ClientCallDetails.
"""

from collections import namedtuple
from grpc import ClientCallDetails
import json


_REQUEST_ID_KEY = 'request-id'

class InterceptorMixin:
    @classmethod
    def get_request_id_from_metadata(self, trailing_metadata):
        """Gets the request ID for the Google Ads API request.

        Args:
            trailing_metadata: a tuple of metadatum from the service response.

        Returns:
            A str request ID associated with the Google Ads API request, or None
            if it doesn't exist.
        """
        for kv in trailing_metadata:
            if kv[0] == _REQUEST_ID_KEY:
                return kv[1]  # Return the found request ID.

        return None

    @classmethod
    def parse_metadata_to_json(self, metadata):
        """Parses metadata from gRPC request and response messages to a JSON str.

        Obscures the value for "developer-token".

        Args:
            metadata: a tuple of metadatum.
        """
        SENSITIVE_INFO_MASK = 'REDACTED'
        metadata_dict = {}

        if metadata is None:
            return '{}'

        for datum in metadata:
            key = datum[0]
            if key == 'developer-token':
                metadata_dict[key] = SENSITIVE_INFO_MASK
            else:
                value = datum[1]
                metadata_dict[key] = value

        return self.format_json_object(metadata_dict)

    @classmethod
    def format_json_object(self, obj):
        """Parses a serializable object into a consistently formatted JSON string.

        Returns:
            A str of formatted JSON serialized from the given object.

        Args:
            obj: an object or dict.
        """

        def default_serializer(value):
            if isinstance(value, bytes):
                return value.decode(errors='ignore')
            else:
                return None

        return str(json.dumps(obj, indent=2, sort_keys=True, ensure_ascii=False,
                              default=default_serializer,
                              separators=(',', ': ')))

    @classmethod
    def get_trailing_metadata_from_interceptor_exception(self, exception):
        """Retrieves trailing metadata from an exception object.

        Args:
            exception: an instance of grpc.Call.

        Returns:
            A tuple of trailing metadata key value pairs.
        """
        try:
            # GoogleAdsFailure exceptions will contain trailing metadata on the
            # error attribute.
            return exception.error.trailing_metadata()
        except AttributeError:
            try:
                # Transport failures, i.e. issues at the gRPC layer, will contain
                # trailing metadata on the exception itself.
                return exception.trailing_metadata()
            except AttributeError:
                # if trailing metadata is not found in either location then
                # return an empty tuple
                return tuple()

    @classmethod
    def get_client_call_details_instance(cls, method, timeout, metadata,
                                         credentials=None):
        """Initializes an instance of the ClientCallDetails with the given data.

        Args:
            method: A str of the service method being invoked.
            timeout: A float of the request timeout
            metadata: A list of metadata tuples
            credentials: An optional grpc.CallCredentials instance for the RPC
        """
        class _ClientCallDetails(
            namedtuple(
                '_ClientCallDetails',
                ('method', 'timeout', 'metadata', 'credentials')),
            ClientCallDetails):
            """Wrapper class for initializing a new ClientCallDetails instance.
            """
            pass

        return _ClientCallDetails(method, timeout, metadata, credentials)